@@ -109,18 +109,19 @@ class TestBasicFunctionalityTags(TestCase):
         self.assertTrue('email-fields' in html)
 
     def test_crispy_field_and_class_converters(self):
-        template = get_template_from_string(u"""
-            {% load crispy_forms_field %}
-            {% crispy_field testField 'class' 'error' %}
-        """)
-        test_form = TestForm()
-        field_instance = test_form.fields['email']
-        bound_field = BoundField(test_form, field_instance, 'email')
+        if hasattr(settings, 'CRISPY_CLASS_CONVERTERS'):
+            template = get_template_from_string(u"""
+                {% load crispy_forms_field %}
+                {% crispy_field testField 'class' 'error' %}
+            """)
+            test_form = TestForm()
+            field_instance = test_form.fields['email']
+            bound_field = BoundField(test_form, field_instance, 'email')
 
-        c = Context({'testField': bound_field})
-        html = template.render(c)
-        self.assertTrue('error' in html)
-        self.assertTrue('inputtext' in html)
+            c = Context({'testField': bound_field})
+            html = template.render(c)
+            self.assertTrue('error' in html)
+            self.assertTrue('inputtext' in html)
 
 
 class TestFormHelpers(TestCase):
@@ -1091,7 +1092,8 @@ class TestLayoutObjects(TestCase):
         test_form.helper.layout = Layout(
             TabHolder(
                 Tab('one',
-                    'first_name'
+                    'first_name',
+                    css_id="custom-name"
                 ),
                 Tab('two',
                     'password1',
@@ -1102,10 +1104,10 @@ class TestLayoutObjects(TestCase):
         html = render_crispy_form(test_form)
 
         self.assertEqual(html.count(
-            '<li class="tab-pane active"><a href="#one" data-toggle="tab">One</a></li>'), 1)
+            '<li class="tab-pane active"><a href="#custom-name" data-toggle="tab">One</a></li>'), 1)
         self.assertEqual(html.count('<li class="tab-pane'), 2)
         self.assertEqual(html.count('tab-pane'), 4)
-        self.assertEqual(html.count('<div id="one"'), 1)
+        self.assertEqual(html.count('<div id="custom-name"'), 1)
         self.assertEqual(html.count('<div id="two"'), 1)
         self.assertEqual(html.count('name="first_name"'), 1)
         self.assertEqual(html.count('name="password1"'), 1)
@@ -1534,6 +1536,14 @@ class TestDynamicLayouts(TestCase):
         helper.layout = layout
         helper['email'].wrap(Field, css_class='hero')
         self.assertTrue(isinstance(layout[0][0], Field))
+        self.assertEqual(layout[0][0][0], 'email')
+
+        helper = FormHelper()
+        helper.layout = Layout('password1')
+        helper['password1'].wrap(AppendedText, "extra")
+        self.assertTrue(isinstance(helper.layout[0], AppendedText))
+        self.assertEqual(helper.layout[0][0], 'password1')
+        self.assertEqual(helper.layout[0].text, 'extra')
 
     def test_formhelper__setitem__(self):
         helper = FormHelper()
